.. _api:

API
############################################

.. develop a small description for the API [CHANGE THIS]:

Welcome to the API documentation for this project.


.. remove this note after enter maintenance mode [CHANGE THIS]:

.. warning::

    This API documentation is under active development


.. list down here all modules that must be in the API [CHANGE THIS]:


.. autosummary::
   :toctree: generated

   babilonia


.. autosummary::
   :toctree: generated

   babilonia.root


.. autosummary::
   :toctree: generated

   babilonia.accounting

.. autosummary::
   :toctree: generated

   babilonia.tools.core

.. autosummary::
   :toctree: generated

   babilonia.tools.parse

.. autosummary::
   :toctree: generated

   babilonia.tools.cashflow

.. autosummary::
   :toctree: generated

   babilonia.tools.report
